# JAKT
Jakt is just another (k)ommand-line timetracker tool. 

## But what is it? 
Jakt helps you keep track of how you spend your time. Whether you want to keep better track of how much time you spend on each project or want to keep yourself accountable while working, jakt is the perfect tool.

## The name
The name comes from the norwegian word for hunt. Timetracking is one of the best tools in your arsenal in your hunt for productivity.  
And if you are wondering, yes, I started with the acronym. 

## Features
Jakt is a tool for timetracking. It has support for:
- Projects
- Tags
- Live tracking from commandline
- Manually adding time that is not tracked live
- A python library that can be used in other applications

For feature requests please open an [issue](https://github.com/kwillno/jakt/issues).

## Installation
Jakt can be installed from PyPI using:
```
pip install jakt
```

You can then start using jakt by simply typing 
```jakt```
in any terminal.

### From Source
1. Clone the repo
2. `cd jakt` 
3. `pip install -e .`  
	Make sure to use the correct version of pip, some users will need to use `pip3` instead. 


## License 
This project is licensed under the MIT License. See [LICENSE](https://github.com/kwillno/jakt/blob/main/LICENSE). 
